@@ -42,12 +42,15 @@
     STMT_START {					\
 	StartSockets();					\
 	if((x) == (y))					\
-	    errno = get_last_socket_error();		\
+	    {						\
+	    int wsaerr = WSAGetLastError();		\
+	    errno = convert_wsa_error_to_errno(wsaerr);	\
+	    SetLastError(wsaerr);			\
+	    }						\
     } STMT_END
 
 #define SOCKET_TEST_ERROR(x) SOCKET_TEST(x, SOCKET_ERROR)
 
-static int get_last_socket_error(void);
 static struct servent* win32_savecopyservent(struct servent*d,
                                              struct servent*s,
                                              const char *proto);
@@ -322,12 +325,6 @@ convert_errno_to_wsa_error(int err)
 }
 #endif /* ERRNO_HAS_POSIX_SUPPLEMENT */
 
-static int
-get_last_socket_error(void)
-{
-    return convert_wsa_error_to_errno(WSAGetLastError());
-}
-
 void
 start_sockets(void) 
 {
@@ -616,7 +613,7 @@ open_ifs_socket(int af, int type, int protocol)
     dTHX;
     char *s;
     unsigned long proto_buffers_len = 0;
-    int error_code;
+    int error_code, found = 0;
     SOCKET out = INVALID_SOCKET;
 
     if ((s = PerlEnv_getenv("PERL_ALLOW_NON_IFS_LSP")) && atoi(s))
@@ -648,11 +645,15 @@ open_ifs_socket(int af, int type, int protocol)
                 if ((proto_buffers[i].dwServiceFlags1 & XP1_IFS_HANDLES) == 0)
                     continue;
 
+                found = 1;
                 convert_proto_info_w2a(&(proto_buffers[i]), &proto_info);
 
                 out = WSASocket(af, type, protocol, &proto_info, 0, 0);
                 break;
             }
+
+            if (!found)
+                WSASetLastError(WSAEPROTONOSUPPORT);
         }
 
         Safefree(proto_buffers);
@@ -669,7 +670,11 @@ win32_socket(int af, int type, int protocol)
     StartSockets();
 
     if((s = open_ifs_socket(af, type, protocol)) == INVALID_SOCKET)
-	errno = get_last_socket_error();
+        {
+	int wsaerr = WSAGetLastError();
+	errno = convert_wsa_error_to_errno(wsaerr);
+	SetLastError(wsaerr);
+	}
     else
 	s = OPEN_SOCKET(s);
 
@@ -693,16 +698,23 @@ int my_close(int fd)
 	int err;
 	err = closesocket(osf);
 	if (err == 0) {
+#ifdef _set_osfhnd
 	    assert(_osfhnd(fd) == osf); /* catch a bad ioinfo struct def */
 	    /* don't close freed handle */
 	    _set_osfhnd(fd, INVALID_HANDLE_VALUE);
 	    return close(fd);
+#else
+	    (void)close(fd);    /* handle already closed, ignore error */
+	    return 0;
+#endif
 	}
 	else if (err == SOCKET_ERROR) {
-	    err = get_last_socket_error();
+	    int wsaerr = WSAGetLastError();
+	    err = convert_wsa_error_to_errno(wsaerr);
 	    if (err != ENOTSOCK) {
 		(void)close(fd);
 		errno = err;
+		SetLastError(wsaerr);
 		return EOF;
 	    }
 	}
@@ -723,16 +735,23 @@ my_fclose (FILE *pf)
 	win32_fflush(pf);
 	err = closesocket(osf);
 	if (err == 0) {
+#ifdef _set_osfhnd
 	    assert(_osfhnd(win32_fileno(pf)) == osf); /* catch a bad ioinfo struct def */
 	    /* don't close freed handle */
 	    _set_osfhnd(win32_fileno(pf), INVALID_HANDLE_VALUE);
 	    return fclose(pf);
+#else
+	    (void)fclose(pf);   /* handle already closed, ignore error */
+	    return 0;
+#endif
 	}
 	else if (err == SOCKET_ERROR) {
-	    err = get_last_socket_error();
+	    int wsaerr = WSAGetLastError();
+	    err = convert_wsa_error_to_errno(wsaerr);
 	    if (err != ENOTSOCK) {
 		(void)fclose(pf);
 		errno = err;
+		SetLastError(wsaerr);
 		return EOF;
 	    }
 	}
@@ -830,12 +849,14 @@ win32_ioctl(int i, unsigned int u, char *data)
     memcpy(data, &u_long_arg, sizeof u_long_arg);
     
     if (retval == SOCKET_ERROR) {
-	int err = get_last_socket_error();
+	int wsaerr = WSAGetLastError();
+	int err = convert_wsa_error_to_errno(wsaerr);
 	if (err == ENOTSOCK) {
 	    Perl_croak_nocontext("ioctl implemented only on sockets");
 	    /* NOTREACHED */
 	}
 	errno = err;
+	SetLastError(wsaerr);
     }
     return retval;
 }
